@@ -1,20 +1,17 @@
 package CDB_File;
 
 use strict;
-use Carp;
-use vars qw($VERSION @ISA @EXPORT_OK);
 
-use DynaLoader ();
+use XSLoader ();
 use Exporter ();
 
-@ISA = qw(Exporter DynaLoader);
-@EXPORT_OK = qw(create);
-
-$VERSION = '0.96';
+our @ISA       = qw(XSLoader Exporter);
+our $VERSION   = '0.99';
+our @EXPORT_OK = qw(create);
 
 =head1 NAME
 
-CDB_File - Perl extension for access to cdb databases 
+CDB_File - Perl extension for access to cdb databases
 
 =head1 SYNOPSIS
 
@@ -41,7 +38,7 @@ or
 =head1 DESCRIPTION
 
 B<CDB_File> is a module which provides a Perl interface to Dan
-Berstein's B<cdb> package:
+Bernstein's B<cdb> package:
 
     cdb is a fast, reliable, lightweight package for creating and
     reading constant databases.
@@ -147,9 +144,9 @@ file.
         }
         return @result;
     }
-    
+
     my $chunk = 8192;
-    
+
     sub extract {
         my($file, $t, $b) = @_;
         my $head = $$b{"H$file"};
@@ -243,7 +240,7 @@ more efficient.
 
     foreach $key (keys %catalogue) {
             print "$key:$catalogue{$key} ";
-    } 
+    }
 
     while (($key, $val) = each %catalogue) {
             print "$key:$val ";
@@ -264,6 +261,17 @@ reference.
     warn "$key not found\n" unless $x; # WRONG; message never printed
     warn "$key not found\n" unless @$x; # Correct
 
+The C<fetch_all> method returns a hashref of all keys with the first
+value in the cdb.  This is useful for quickly loading a cdb file where
+there is a 1:1 key mapping.  In practice it proved to be about 400%
+faster then iterating a tied hash.
+
+    # Slow
+    my %copy = %tied_cdb;
+
+    # Much Faster
+    my $copy_hashref = $catref->fetch_all();
+
 =head1 RETURN VALUES
 
 The routines C<tie>, C<new>, and C<finish> return B<undef> if the
@@ -324,30 +332,31 @@ Now maintained by Matt Sergeant, <matt@sergeant.org>
 
 =cut
 
-bootstrap CDB_File $VERSION;
+XSLoader::load( 'CDB_File', $VERSION );
 
 sub CLEAR {
-	croak "Modification of a CDB_File attempted"
+    require Carp;
+    Carp::croak("Modification of a CDB_File attempted");
 }
 
 sub DELETE {
-	&CLEAR
+    &CLEAR;
 }
 
 sub STORE {
-	&CLEAR
+    &CLEAR;
 }
 
 # Must be preloaded for the prototype.
 
 sub create(\%$$) {
-        my($RHdata, $fn, $fntemp) = @_;
+    my ( $RHdata, $fn, $fntemp ) = @_;
 
-        my $cdb = new CDB_File($fn, $fntemp) or return undef;
-        my($k, $v);
-        $cdb->insert(%$RHdata);
-        $cdb->finish;
-        return 1;
+    my $cdb = new CDB_File( $fn, $fntemp ) or return undef;
+    my ( $k, $v );
+    $cdb->insert(%$RHdata);
+    $cdb->finish;
+    return 1;
 }
 
 1;
